@@ -4,15 +4,13 @@ from deprecation import deprecated
 from square.api_helper import APIHelper
 from square.http.api_response import ApiResponse
 from square.api.base_api import BaseApi
-from square.http.auth.o_auth_2 import OAuth2
 
 
 class CustomersApi(BaseApi):
 
     """A Controller to access Endpoints in the square API."""
-
-    def __init__(self, config, call_back=None):
-        super(CustomersApi, self).__init__(config, call_back)
+    def __init__(self, config, auth_managers):
+        super(CustomersApi, self).__init__(config, auth_managers)
 
     def list_customers(self,
                        cursor=None,
@@ -34,15 +32,16 @@ class CustomersApi(BaseApi):
                 previous call to this endpoint. Provide this cursor to
                 retrieve the next set of results for your original query.  For
                 more information, see
-                [Pagination](https://developer.squareup.com/docs/working-with-a
-                pis/pagination).
+                [Pagination](https://developer.squareup.com/docs/build-basics/c
+                ommon-api-patterns/pagination).
             limit (int, optional): The maximum number of results to return in
                 a single page. This limit is advisory. The response might
-                contain more or fewer results. The limit is ignored if it is
-                less than 1 or greater than 100. The default value is 100. 
-                For more information, see
-                [Pagination](https://developer.squareup.com/docs/working-with-a
-                pis/pagination).
+                contain more or fewer results. If the specified limit is less
+                than 1 or greater than 100, Square returns a `400
+                VALUE_TOO_LOW` or `400 VALUE_TOO_HIGH` error. The default
+                value is 100.  For more information, see
+                [Pagination](https://developer.squareup.com/docs/build-basics/c
+                ommon-api-patterns/pagination).
             sort_field (CustomerSortField, optional): Indicates how customers
                 should be sorted.  The default value is `DEFAULT`.
             sort_order (SortOrder, optional): Indicates whether customers
@@ -84,7 +83,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -140,7 +141,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -199,7 +202,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -230,9 +235,9 @@ class CustomersApi(BaseApi):
             version (long|int, optional): The current version of the customer
                 profile.  As a best practice, you should include this
                 parameter to enable [optimistic
-                concurrency](https://developer.squareup.com/docs/working-with-a
-                pis/optimistic-concurrency) control.  For more information,
-                see [Delete a customer
+                concurrency](https://developer.squareup.com/docs/build-basics/c
+                ommon-api-patterns/optimistic-concurrency) control.  For more
+                information, see [Delete a customer
                 profile](https://developer.squareup.com/docs/customers-api/use-
                 the-api/keep-records#delete-customer-profile).
 
@@ -271,7 +276,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.delete(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -319,7 +326,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -383,7 +392,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -443,7 +454,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -496,7 +509,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.delete(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -551,7 +566,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.delete(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -605,7 +622,9 @@ class CustomersApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.put(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
