@@ -17,8 +17,8 @@ class MerchantsApiTests(ApiTestBase):
     @classmethod
     def setUpClass(cls):
         super(MerchantsApiTests, cls).setUpClass()
-        cls.response_catcher = HttpResponseCatcher()
-        cls.controller = MerchantsApi(cls.config, cls.response_catcher)
+        cls.controller = cls.client.merchants
+        cls.response_catcher = cls.controller.http_call_back
 
     # Returns `Merchant` information for a given access token.
     #
